==> MCRestimate_2.2.0.zip: MCRestimate/doc/UsingMCRestimate.R <==
###################################################
### chunk number 1: arguments
###################################################
library(MCRestimate)
library(randomForest)
library(golubEsets)
data(Golub_Train)
class.colum <- "ALL.AML"


###################################################
### chunk number 2: the functions
###################################################
savepdf =function(x,file,w=10,h=5){pdf(file=file,width=w,height=w);x;dev.off()}
options(width=50)


###################################################
### chunk number 3: METHOD CHOISE
###################################################
Preprocessingfunctions        <- c("varSel.highest.var")
list.of.poss.parameter        <- list(var.numbers=c(250,1000))


###################################################
### chunk number 4: METHOD CHOISE
###################################################
class.function                    <- "RF.wrap"


###################################################
### chunk number 5: PLOT PARAMETER
###################################################
plot.label               <- "Samples"


###################################################
### chunk number 6: ARGUMENTS FOR CROSS-VALIDSATION
###################################################
cross.outer        <- 2
cross.repeat       <- 3
cross.inner        <- 2


###################################################
### chunk number 7: RF.make
###################################################
RF.estimate <- MCRestimate(Golub_Train,
                        class.colum,
                        classification.fun="RF.wrap",
                        thePreprocessingMethods=Preprocessingfunctions,
                        poss.parameters=list.of.poss.parameter,
                        cross.outer=cross.outer,
                        cross.inner=cross.inner,
                        cross.repeat=cross.repeat,
                        plot.label=plot.label)


###################################################
### chunk number 8: rf.show
###################################################
class(RF.estimate)


###################################################
### chunk number 9: RF eval=FALSE
###################################################
## plot(RF.estimate,rownames.from.object=TRUE, main="Random Forest")


###################################################
### chunk number 10: rf.save
###################################################
savepdf(plot(RF.estimate,rownames.from.object=TRUE, main="Random Forest"),"RF.pdf")


###################################################
### chunk number 11: 
###################################################
RF.classifier <- ClassifierBuild (Golub_Train, 
                                 class.colum,
                                 classification.fun="RF.wrap",
				 thePreprocessingMethods=Preprocessingfunctions,
                                 poss.parameters=list.of.poss.parameter,
                                 cross.inner=cross.inner)


###################################################
### chunk number 12: 
###################################################
names(RF.classifier)


###################################################
### chunk number 13: test
###################################################
data(Golub_Test)
RF.classifier$classifier.for.exprSet(Golub_Test)

==> MCRestimate_2.6.0.zip: MCRestimate/doc/UsingMCRestimate.R <==
###################################################
### chunk number 1: arguments
###################################################
#line 42 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
library(MCRestimate)
library(randomForest)
library(golubEsets)
data(Golub_Train)
class.colum <- "ALL.AML"


###################################################
### chunk number 2: the functions
###################################################
#line 50 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
savepdf =function(x,file,w=10,h=5){pdf(file=file,width=w,height=w);x;dev.off()}
options(width=50)


###################################################
### chunk number 3: METHOD CHOISE
###################################################
#line 67 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
Preprocessingfunctions        <- c("varSel.highest.var")
list.of.poss.parameter        <- list(var.numbers=c(250,1000))


###################################################
### chunk number 4: METHOD CHOISE
###################################################
#line 85 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
class.function                    <- "RF.wrap"


###################################################
### chunk number 5: PLOT PARAMETER
###################################################
#line 101 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
plot.label               <- "Samples"


###################################################
### chunk number 6: ARGUMENTS FOR CROSS-VALIDSATION
###################################################
#line 110 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
cross.outer        <- 2
cross.repeat       <- 3
cross.inner        <- 2


###################################################
### chunk number 7: RF.make
###################################################
#line 119 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
RF.estimate <- MCRestimate(Golub_Train,
                        class.colum,
                        classification.fun="RF.wrap",
                        thePreprocessingMethods=Preprocessingfunctions,
                        poss.parameters=list.of.poss.parameter,
                        cross.outer=cross.outer,
                        cross.inner=cross.inner,
                        cross.repeat=cross.repeat,
                        plot.label=plot.label)


###################################################
### chunk number 8: rf.show
###################################################
#line 131 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
class(RF.estimate)


###################################################
### chunk number 9: RF eval=FALSE
###################################################
## #line 138 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
## plot(RF.estimate,rownames.from.object=TRUE, main="Random Forest")


###################################################
### chunk number 10: rf.save
###################################################
#line 142 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
savepdf(plot(RF.estimate,rownames.from.object=TRUE, main="Random Forest"),"RF.pdf")


###################################################
### chunk number 11: 
###################################################
#line 158 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
RF.classifier <- ClassifierBuild (Golub_Train, 
                                 class.colum,
                                 classification.fun="RF.wrap",
				 thePreprocessingMethods=Preprocessingfunctions,
                                 poss.parameters=list.of.poss.parameter,
                                 cross.inner=cross.inner)


###################################################
### chunk number 12: 
###################################################
#line 168 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
names(RF.classifier)


###################################################
### chunk number 13: test
###################################################
#line 178 "E:/biocbld/bbs-2.7-bioc/tmpdir/RtmpbCYXHy/R.INSTALL20144682/MCRestimate/inst/doc/UsingMCRestimate.Rnw"
data(Golub_Test)
RF.classifier$classifier.for.exprSet(Golub_Test)
